@@ -16,7 +16,7 @@ use Data::Page;
 
 our $Cache = undef;
 
-our $VERSION = 1.110420;# VERSION
+our $VERSION = 1.110421;# VERSION
 
 
 sub new {
@@ -294,11 +294,11 @@ sub count {
     if (defined $whr) {
         my @columns = $dbo->_protect_sql($dbo->key || '*');
         my $counter = 'COUNT('. $columns[0] .')';
-        return scalar @{$dbo->select($counter)->read($whr)->{collection}};
-    }
-    else {
-        return scalar @{$dbo->{collection}};
+        $dbo->select($counter)->read($whr);
+        return scalar $dbo->list;
     }
+    
+    return scalar @{$dbo->{collection}};
 }
 
 
@@ -696,7 +696,7 @@ ORMesque - Lightweight To-The-Point ORM
 
 =head1 VERSION
 
-version 1.110420
+version 1.110421
 
 =head1 SYNOPSIS
 
@@ -774,9 +774,9 @@ methods. The following is an example of how this should be done using ORMesque.
     # note the model should be named after the table, the naming is as follows:
     
     # Schema Table Classes are CamelCased for convention, all class names are
-    # lowercase, capitalized, and have dashed and underscores removed.
-    # for example ...
-    # table 'user_workplace' would generate a class named 'UserWorkspace'
+    # titlecased, and have dashed and underscores removed.
+    
+    # e.g. table 'user_workplace' would generate a class named 'UserWorkspace'
     
     # with no special characters. If package name is one of the auto-generated
     # classes, all relevant methods and settings will be set automatically.
@@ -907,11 +907,13 @@ methods. The following is an example of how this should be done using ORMesque.
     my $count = $db->read->count;
     
     Note! The count() method DOES NOT query the database, it merely counts
-    the number of items in the existing resultset. Alternatively to perform a
-    count-type-of query you can use the count($where) syntax:
+    the number of items in the existing resultset produced by read().
+    Alternatively, to perform a type-of SQL COUNT() query you can use the
+    count($where) syntax:
     
     my $db = ORMesque->new(...)->table;
     my $count = $db->count({ id => 12345});
+    # notice there is no read() command
 
 =head2 create
 
